@@ -95,9 +95,7 @@ namespace gnote {
   {
     if(!m_inhibit_activate) {
       if(m_note) {
-        MainWindow::present_in_new_window(m_note,
-          Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
-            Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
+        MainWindow::present_in_new_window(m_note, true);
       }
     }
   }
@@ -365,8 +363,7 @@ namespace gnote {
     MainWindow &win = IGnote::obj().new_main_window();
     win.new_note();
     win.present();
-    win.close_on_escape(Preferences::obj().get_schema_settings(
-      Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
+    win.close_on_escape(true);
   }
 
   void Tray::on_search_notes_activate()
