@@ -35,6 +35,7 @@
 #include <glibmm/i18n.h>
 #include <glibmm/stringutils.h>
 #include <glibmm/threads.h>
+#include <gtkmm/checkmenuitem.h>
 #include <gtkmm/icontheme.h>
 #include <gtkmm/image.h>
 #include <gtkmm/label.h>
@@ -819,5 +820,24 @@ namespace gnote {
       set_active(false);
     }
 
+
+    CheckAction::CheckAction(const Glib::ustring & name)
+      : Gtk::Action(name)
+      , m_checked(false)
+    {}
+
+    Gtk::Widget *CheckAction::create_menu_item_vfunc()
+    {
+      Gtk::CheckMenuItem *item = new Gtk::CheckMenuItem;
+      item->set_active(m_checked);
+      return item;
+    }
+
+    void CheckAction::on_activate()
+    {
+      m_checked = !m_checked;
+      Gtk::Action::on_activate();
+    }
+
   }
 }
