@@ -282,6 +282,9 @@ namespace gnote {
 
 
 #if FIXED_GTKSPELL
+  const char *NoteSpellChecker::LANG_PREFIX = "spellchecklang:";
+  const char *NoteSpellChecker::LANG_DISABLED = "disabled";
+
   void NoteSpellChecker::shutdown ()
   {
     detach();
@@ -299,6 +302,20 @@ namespace gnote {
   }
 
   void NoteSpellChecker::attach ()
+  {
+    attach_checker();
+
+    m_enable_action = utils::CheckAction::create("EnableSpellCheck");
+    m_enable_action->set_label(_("Check spelling"));
+    m_enable_action->set_tooltip(_("Check spelling in this note"));
+    m_enable_action->checked(get_language() != LANG_DISABLED);
+    m_enable_action->signal_activate()
+      .connect(sigc::mem_fun(*this, &NoteSpellChecker::on_spell_check_enable_action));
+    add_note_action(m_enable_action, 800);
+  }
+
+
+  void NoteSpellChecker::attach_checker()
   {
     // Make sure we add this tag before attaching, so
     // gtkspell will use our version.
@@ -312,14 +329,28 @@ namespace gnote {
     m_tag_applied_cid = get_buffer()->signal_apply_tag().connect(
       sigc::mem_fun(*this, &NoteSpellChecker::tag_applied), false);  // connect before
 
-    if (!m_obj_ptr) {
+    std::string lang = get_language();
+
+    if (!m_obj_ptr && lang != LANG_DISABLED) {
       m_obj_ptr = gtk_spell_checker_new();
+      if(lang != "") {
+        gtk_spell_checker_set_language(m_obj_ptr, lang.c_str(), NULL);
+      }
+      g_signal_connect(G_OBJECT(m_obj_ptr), "language-changed", G_CALLBACK(language_changed), this);
       gtk_spell_checker_attach(m_obj_ptr, get_window()->editor()->gobj());
     }
   }
 
 
   void NoteSpellChecker::detach ()
+  {
+    detach_checker();
+    get_window()->remove_widget_action("EnableSpellCheck");
+    m_enable_action.reset();
+  }
+
+
+  void NoteSpellChecker::detach_checker()
   {
     m_tag_applied_cid.disconnect();
     
@@ -377,6 +408,70 @@ namespace gnote {
                                start_char, end_char);
     }
   }
+
+  void NoteSpellChecker::language_changed(GtkSpellChecker*, gchar *lang, NoteSpellChecker *checker)
+  {
+    try {
+      checker->on_language_changed(lang);
+    }
+    catch(...) {
+    }
+  }
+
+  void NoteSpellChecker::on_language_changed(const gchar *lang)
+  {
+    std::string tag_name = LANG_PREFIX;
+    tag_name += lang;
+    Tag::Ptr tag = get_language_tag();
+    if(tag && tag->name() != tag_name) {
+      get_note()->remove_tag(tag);
+    }
+    tag = ITagManager::obj().get_or_create_tag(tag_name);
+    get_note()->add_tag(tag);
+    DBG_OUT("Added language tag %s", tag_name.c_str());
+  }
+
+  Tag::Ptr NoteSpellChecker::get_language_tag()
+  {
+    Tag::Ptr lang_tag;
+    std::list<Tag::Ptr> tags;
+    get_note()->get_tags(tags);
+    FOREACH(Tag::Ptr tag, tags) {
+      if(sharp::string_index_of(tag->name(), LANG_PREFIX) == 0) {
+        lang_tag = tag;
+        break;
+      }
+    }
+    return lang_tag;
+  }
+
+  std::string NoteSpellChecker::get_language()
+  {
+    Tag::Ptr tag = get_language_tag();
+    std::string lang;
+    if(tag) {
+      lang = sharp::string_replace_first(tag->name(), LANG_PREFIX, "");
+    }
+    return lang;
+  }
+
+  void NoteSpellChecker::on_spell_check_enable_action()
+  {
+    Tag::Ptr tag = get_language_tag();
+    if(tag) {
+      get_note()->remove_tag(tag);
+    }
+    if(m_enable_action->checked()) {
+      attach_checker();
+    }
+    else {
+      std::string tag_name = LANG_PREFIX;
+      tag_name += LANG_DISABLED;
+      tag = ITagManager::obj().get_or_create_tag(tag_name);
+      get_note()->add_tag(tag);
+      detach_checker();
+    }
+  }
 #endif
   
   ////////////////////////////////////////////////////////////////////////
@@ -961,38 +1056,13 @@ namespace gnote {
 
   void NoteWikiWatcher::on_note_opened ()
   {
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(
-        Preferences::SCHEMA_GNOTE);
-    if (settings->get_boolean(Preferences::ENABLE_WIKIWORDS)) {
-      m_on_insert_text_cid = get_buffer()->signal_insert().connect(
-        sigc::mem_fun(*this, &NoteWikiWatcher::on_insert_text));
-      m_on_delete_range_cid = get_buffer()->signal_erase().connect(
-        sigc::mem_fun(*this, &NoteWikiWatcher::on_delete_range));
-    }
-    settings->signal_changed()
-      .connect(sigc::mem_fun(*this, &NoteWikiWatcher::on_enable_wikiwords_changed));
+    get_buffer()->signal_insert().connect(
+      sigc::mem_fun(*this, &NoteWikiWatcher::on_insert_text));
+    get_buffer()->signal_erase().connect(
+      sigc::mem_fun(*this, &NoteWikiWatcher::on_delete_range));
   }
 
 
-  void NoteWikiWatcher::on_enable_wikiwords_changed(const Glib::ustring & key)
-  {
-    if(key != Preferences::ENABLE_WIKIWORDS) {
-      return;
-    }
-    bool value = Preferences::obj().get_schema_settings(
-        Preferences::SCHEMA_GNOTE)->get_boolean(key);
-    if (value) {
-      m_on_insert_text_cid = get_buffer()->signal_insert().connect(
-        sigc::mem_fun(*this, &NoteWikiWatcher::on_insert_text));
-      m_on_delete_range_cid = get_buffer()->signal_erase().connect(
-        sigc::mem_fun(*this, &NoteWikiWatcher::on_delete_range));
-    } 
-    else {
-      m_on_insert_text_cid.disconnect();
-      m_on_delete_range_cid.disconnect();
-    }
-  }
-
   void NoteWikiWatcher::apply_wikiword_to_block (Gtk::TextIter start, Gtk::TextIter end)
   {
     NoteBuffer::get_block_extents (start,
